@@ -115,7 +115,7 @@ jsPropensityGadget <- function(data, nfactor.limit = 20) {
               withLoader(DTOutput("table1_original"), type = "html", loader = "loader6"),
               wellPanel(
                 h5("Normal continuous variables  are summarized with Mean (SD) and t-test(2 groups) or ANOVA(> 2 groups)"),
-                h5("Non-normal continuous variables are summarized with median [IQR or min,max] and kruskal-wallis test"),
+                h5("Non-normal continuous variables are summarized with median [IQR or min,max] and wilcox(2 groups)/kruskal-wallis(>3 groups) test"),
                 h5("Categorical variables  are summarized with table")
               )
             ),
@@ -124,7 +124,7 @@ jsPropensityGadget <- function(data, nfactor.limit = 20) {
               withLoader(DTOutput("table1_ps"), type = "html", loader = "loader6"),
               wellPanel(
                 h5("Normal continuous variables  are summarized with Mean (SD) and t-test(2 groups) or ANOVA(> 2 groups)"),
-                h5("Non-normal continuous variables are summarized with median [IQR or min,max] and kruskal-wallis test"),
+                h5("Non-normal continuous variables are summarized with median [IQR or min,max] and wilcox(2 groups)/kruskal-wallis(>3 groups) test"),
                 h5("Categorical variables  are summarized with table")
               )
             ),
@@ -1137,7 +1137,7 @@ jsPropensityExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
               withLoader(DTOutput("table1_original"), type = "html", loader = "loader6"),
               wellPanel(
                 h5("Normal continuous variables  are summarized with Mean (SD) and t-test(2 groups) or ANOVA(> 2 groups)"),
-                h5("Non-normal continuous variables are summarized with median [IQR or min,max] and kruskal-wallis test"),
+                h5("Non-normal continuous variables are summarized with median [IQR or min,max] and wilcox(2 groups)/kruskal-wallis(>3 groups) test"),
                 h5("Categorical variables  are summarized with table")
               )
             ),
@@ -1146,7 +1146,7 @@ jsPropensityExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
               withLoader(DTOutput("table1_ps"), type = "html", loader = "loader6"),
               wellPanel(
                 h5("Normal continuous variables  are summarized with Mean (SD) and t-test(2 groups) or ANOVA(> 2 groups)"),
-                h5("Non-normal continuous variables are summarized with median [IQR or min,max] and kruskal-wallis test"),
+                h5("Non-normal continuous variables are summarized with median [IQR or min,max] and wilcox(2 groups)/kruskal-wallis(>3 groups) test"),
                 h5("Categorical variables  are summarized with table")
               )
             ),
